package com.ruoyi.web.controller.info;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TeacherInfo;
import com.ruoyi.system.service.ITeacherInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 老师档案信息Controller
 * 
 * @author ruoyi
 * @date 2023-07-24
 */
@RestController
@RequestMapping("/teacher/info")
public class TeacherInfoController extends BaseController
{
    @Autowired
    private ITeacherInfoService teacherInfoService;

    /**
     * 查询老师档案信息列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(TeacherInfo teacherInfo)
    {
        startPage();
        List<TeacherInfo> list = teacherInfoService.selectTeacherInfoList(teacherInfo);
        return getDataTable(list);
    }

    /**
     * 导出老师档案信息列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:info:export')")
    @Log(title = "老师档案信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TeacherInfo teacherInfo)
    {
        List<TeacherInfo> list = teacherInfoService.selectTeacherInfoList(teacherInfo);
        ExcelUtil<TeacherInfo> util = new ExcelUtil<TeacherInfo>(TeacherInfo.class);
        util.exportExcel(response, list, "老师档案信息数据");
    }

    /**
     * 获取老师档案信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:info:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(teacherInfoService.selectTeacherInfoById(id));
    }

    /**
     * 新增老师档案信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:info:add')")
    @Log(title = "老师档案信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TeacherInfo teacherInfo)
    {
        return teacherInfoService.insertTeacherInfo(teacherInfo);
    }

    /**
     * 修改老师档案信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:info:edit')")
    @Log(title = "老师档案信息", businessType = BusinessType.UPDATE)
    @PostMapping(value = "/put")
    public AjaxResult edit(@RequestBody TeacherInfo teacherInfo)
    {
        return toAjax(teacherInfoService.updateTeacherInfo(teacherInfo));
    }

    /**
     * 删除老师档案信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:info:remove')")
    @Log(title = "老师档案信息", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(teacherInfoService.deleteTeacherInfoByIds(ids));
    }
}
